@@ -17,7 +17,7 @@
 """Accesses the google.datastore.admin.v1 DatastoreAdmin API."""
 
 import functools
-import pkg_resources
+import os
 import warnings
 
 from google.oauth2 import service_account
@@ -43,10 +43,14 @@ from google.cloud.datastore_admin_v1.proto import index_pb2
 from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2
 
+# To avoid importing datastore into admin (which would result in a
+# circular dependency), We exec to get the version via a dict.
+dir_path = os.path.abspath(os.path.dirname(__file__))
+version = {}
+with open(os.path.join(dir_path, "../../datastore/version.py")) as fp:
+    exec(fp.read(), version)
 
-_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
-    "google-cloud-datastore",
-).version
+_GAPIC_LIBRARY_VERSION = version["__version__"]
 
 
 class DatastoreAdminClient(object):
