@@ -15,6 +15,7 @@
 import datetime
 import os
 import unittest
+import warnings
 
 import requests
 import six
@@ -22,10 +23,9 @@ import six
 from google.cloud._helpers import UTC
 from google.cloud import datastore
 from google.cloud.datastore.helpers import GeoPoint
-from google.cloud.environment_vars import GCD_DATASET
+from google.cloud.datastore.client import DATASTORE_DATASET
 from google.cloud.exceptions import Conflict
 
-from test_utils.system import EmulatorCreds
 from test_utils.system import unique_resource_id
 
 from tests.system.utils import clear_datastore
@@ -44,28 +44,31 @@ class Config(object):
 
 
 def clone_client(client):
-    return datastore.Client(
-        project=client.project,
-        namespace=client.namespace,
-        credentials=client._credentials,
-        _http=client._http,
-    )
+    emulator_dataset = os.getenv(DATASTORE_DATASET)
+
+    if emulator_dataset is None:
+        return datastore.Client(
+            project=client.project,
+            namespace=client.namespace,
+            credentials=client._credentials,
+            _http=client._http,
+        )
+    else:
+        return datastore.Client(
+            project=client.project, namespace=client.namespace, _http=client._http,
+        )
 
 
 def setUpModule():
-    emulator_dataset = os.getenv(GCD_DATASET)
+    emulator_dataset = os.getenv(DATASTORE_DATASET)
     # Isolated namespace so concurrent test runs don't collide.
     test_namespace = "ns" + unique_resource_id()
     if emulator_dataset is None:
         Config.CLIENT = datastore.Client(namespace=test_namespace)
     else:
-        credentials = EmulatorCreds()
         http = requests.Session()  # Un-authorized.
         Config.CLIENT = datastore.Client(
-            project=emulator_dataset,
-            namespace=test_namespace,
-            credentials=credentials,
-            _http=http,
+            project=emulator_dataset, namespace=test_namespace, _http=http,
         )
 
 
@@ -100,6 +103,32 @@ class TestDatastoreAllocateIDs(TestDatastore):
         self.assertEqual(len(unique_ids), num_ids)
 
 
+class TestDatastoreReserveIDs(TestDatastore):
+    def test_reserve_ids_sequential(self):
+        # Smoke test to make sure it doesn't blow up. No return value or
+        # verifiable side effect to verify.
+        num_ids = 10
+        Config.CLIENT.reserve_ids_sequential(Config.CLIENT.key("Kind", 1234), num_ids)
+
+    def test_reserve_ids(self):
+        with warnings.catch_warnings(record=True) as warned:
+            num_ids = 10
+            Config.CLIENT.reserve_ids(Config.CLIENT.key("Kind", 1234), num_ids)
+
+        warned = [
+            warning
+            for warning in warned
+            if "reserve_ids_sequential" in str(warning.message)
+        ]
+        assert len(warned) == 1
+
+    def test_reserve_ids_multi(self):
+        # Smoke test to make sure it doesn't blow up. No return value or
+        # verifiable side effect to verify.
+        keys = [Config.CLIENT.key("KIND", 1234), Config.CLIENT.key("KIND", 1235)]
+        Config.CLIENT.reserve_ids_multi(keys)
+
+
 class TestDatastoreSave(TestDatastore):
     @classmethod
     def setUpClass(cls):
@@ -240,7 +269,7 @@ class TestDatastoreQuery(TestDatastore):
         cls.CLIENT.namespace = None
 
         # In the emulator, re-populating the datastore is cheap.
-        if os.getenv(GCD_DATASET) is not None:
+        if os.getenv(DATASTORE_DATASET) is not None:
             # Populate the datastore with the cloned client.
             populate_datastore.add_characters(client=cls.CLIENT)
 
@@ -251,7 +280,7 @@ class TestDatastoreQuery(TestDatastore):
     @classmethod
     def tearDownClass(cls):
         # In the emulator, destroy the query entities.
-        if os.getenv(GCD_DATASET) is not None:
+        if os.getenv(DATASTORE_DATASET) is not None:
             # Use the client for this test instead of the global.
             clear_datastore.remove_all_entities(client=cls.CLIENT)
 
@@ -484,7 +513,7 @@ class TestDatastoreQueryOffsets(TestDatastore):
     @classmethod
     def tearDownClass(cls):
         # In the emulator, destroy the query entities.
-        if os.getenv(GCD_DATASET) is not None:
+        if os.getenv(DATASTORE_DATASET) is not None:
             # Use the client for this test instead of the global.
             clear_datastore.remove_all_entities(client=cls.CLIENT)
 
